==> space_classy-0.6-py3-none-any.whl: classy/taxonomies/bus.py <==
from classy import core

WAVE = [0.44, 0.50, 0.60, 0.65, 0.70, 0.75, 0.80, 0.85, 0.92]
CLASSES = [
    "B",
    "Cg",
    "Cgh",
    "C",
    "Ch",
    "Cb",
    "D",
    "T",
    "Xc",
    "Xk",
    "Xe",
    "X",
    "Ld",
    "K",
    "L",
    "O",
    "Q",
    "Sq",
    "Sl",
    "S",
    "Sk",
    "Sr",
    "Sa",
    "R",
    "A",
    "V",
]


def load_templates():
    """Load the spectral templates of the Bus classes.

    Returns
    -------
    dict
        Dictionary with classes (str) as key and templates as values (classy.Spectrum).
    """

    templates_ = {}

    for class_, props in TEMPLATES.items():

        refl = props["refl_mean"]
        refl_err = props["refl_std"]

        template = core.Spectrum(
            wave=WAVE + [0.55],
            refl=refl + [1],
            refl_err=refl_err + [0],
            class_=class_,
            source=f"Bus and Binzel 2002 - Class {class_}",
            _source="Bus and Binzel 2002",
            id_=f"Template Class {class_}",
        )
        templates_[class_] = template
    return templates_


# Table III in Bus 2002
TEMPLATES = {
    "A": {
        "refl_mean": [0.708, 0.868, 1.109, 1.214, 1.298, 1.311, 1.250, 1.187, 1.143],
        "refl_std": [0.026, 0.014, 0.013, 0.026, 0.038, 0.045, 0.059, 0.066, 0.063],
    },
    "B": {
        "refl_mean": [1.008, 1.004, 0.989, 0.985, 0.978, 0.975, 0.969, 0.961, 0.938],
        "refl_std": [0.022, 0.008, 0.007, 0.011, 0.015, 0.019, 0.023, 0.026, 0.039],
    },
    "C": {
        "refl_mean": [0.936, 0.979, 1.007, 1.013, 1.014, 1.016, 1.014, 1.008, 0.993],
        "refl_std": [0.025, 0.009, 0.009, 0.011, 0.013, 0.015, 0.017, 0.022, 0.034],
    },
    "Cb": {
        "refl_mean": [0.981, 0.995, 0.999, 1.002, 1.002, 1.005, 1.003, 0.994, 0.979],
        "refl_std": [0.018, 0.007, 0.005, 0.008, 0.010, 0.012, 0.015, 0.020, 0.031],
    },
    "Cg": {
        "refl_mean": [0.852, 0.945, 1.018, 1.028, 1.027, 1.025, 1.026, 1.022, 1.007],
        "refl_std": [0.013, 0.013, 0.012, 0.020, 0.020, 0.023, 0.027, 0.036, 0.044],
    },
    "Cgh": {
        "refl_mean": [0.870, 0.962, 0.997, 0.985, 0.972, 0.973, 0.987, 0.991, 0.980],
        "refl_std": [0.025, 0.014, 0.016, 0.027, 0.035, 0.038, 0.042, 0.047, 0.059],
    },
    "Ch": {
        "refl_mean": [0.941, 0.986, 0.991, 0.983, 0.977, 0.982, 0.991, 0.996, 0.993],
        "refl_std": [0.030, 0.010, 0.008, 0.013, 0.018, 0.021, 0.024, 0.028, 0.037],
    },
    "D": {
        "refl_mean": [0.882, 0.951, 1.046, 1.098, 1.150, 1.199, 1.222, 1.247, 1.287],
        "refl_std": [0.029, 0.012, 0.005, 0.006, 0.010, 0.015, 0.018, 0.026, 0.067],
    },
    "K": {
        "refl_mean": [0.863, 0.943, 1.043, 1.087, 1.121, 1.138, 1.125, 1.110, 1.085],
        "refl_std": [0.024, 0.010, 0.010, 0.016, 0.019, 0.018, 0.020, 0.023, 0.038],
    },
    "L": {
        "refl_mean": [0.818, 0.922, 1.066, 1.130, 1.179, 1.207, 1.201, 1.193, 1.188],
        "refl_std": [0.031, 0.013, 0.012, 0.020, 0.025, 0.024, 0.021, 0.020, 0.042],
    },
    "Ld": {
        "refl_mean": [0.799, 0.913, 1.080, 1.163, 1.228, 1.270, 1.280, 1.282, 1.288],
        "refl_std": [0.042, 0.021, 0.018, 0.027, 0.029, 0.034, 0.038, 0.041, 0.067],
    },
    "O": {
        "refl_mean": [0.878, 0.952, 1.022, 1.042, 1.057, 1.036, 0.958, 0.870, 0.798],
        "refl_std": [0.026, 0.007, 0.006, 0.009, 0.012, 0.011, 0.015, 0.033, 0.048],
    },
    "Q": {
        "refl_mean": [0.830, 0.930, 1.047, 1.087, 1.118, 1.107, 1.041, 0.952, 0.873],
        "refl_std": [0.044, 0.018, 0.018, 0.027, 0.032, 0.031, 0.023, 0.019, 0.032],
    },
    "R": {
        "refl_mean": [0.792, 0.907, 1.073, 1.145, 1.209, 1.224, 1.110, 0.971, 0.889],
        "refl_std": [0.016, 0.006, 0.005, 0.006, 0.010, 0.010, 0.014, 0.015, 0.033],
    },
    "S": {
        "refl_mean": [0.813, 0.920, 1.060, 1.121, 1.170, 1.188, 1.145, 1.084, 1.034],
        "refl_std": [0.028, 0.011, 0.012, 0.018, 0.023, 0.024, 0.024, 0.028, 0.040],
    },
    "Sa": {
        "refl_mean": [0.748, 0.892, 1.094, 1.178, 1.243, 1.260, 1.216, 1.150, 1.091],
        "refl_std": [0.029, 0.011, 0.010, 0.014, 0.014, 0.019, 0.025, 0.036, 0.059],
    },
    "Sk": {
        "refl_mean": [0.859, 0.939, 1.039, 1.082, 1.115, 1.130, 1.092, 1.039, 1.001],
        "refl_std": [0.029, 0.011, 0.008, 0.010, 0.012, 0.013, 0.009, 0.011, 0.022],
    },
    "Sl": {
        "refl_mean": [0.790, 0.909, 1.076, 1.149, 1.209, 1.237, 1.205, 1.158, 1.131],
        "refl_std": [0.025, 0.009, 0.009, 0.013, 0.015, 0.017, 0.019, 0.026, 0.042],
    },
    "Sq": {
        "refl_mean": [0.851, 0.938, 1.039, 1.082, 1.115, 1.120, 1.069, 1.000, 0.936],
        "refl_std": [0.031, 0.011, 0.009, 0.017, 0.022, 0.028, 0.028, 0.028, 0.034],
    },
    "Sr": {
        "refl_mean": [0.777, 0.904, 1.069, 1.137, 1.188, 1.193, 1.123, 1.030, 0.936],
        "refl_std": [0.046, 0.023, 0.016, 0.024, 0.028, 0.031, 0.032, 0.028, 0.038],
    },
    "T": {
        "refl_mean": [0.896, 0.956, 1.041, 1.083, 1.119, 1.149, 1.163, 1.174, 1.184],
        "refl_std": [0.027, 0.008, 0.011, 0.016, 0.019, 0.015, 0.015, 0.021, 0.037],
    },
    "V": {
        "refl_mean": [0.808, 0.916, 1.063, 1.124, 1.176, 1.183, 1.048, 0.879, 0.745],
        "refl_std": [0.052, 0.024, 0.019, 0.036, 0.049, 0.049, 0.039, 0.0460, 0.056],
    },
    "X": {
        "refl_mean": [0.940, 0.977, 1.013, 1.030, 1.045, 1.057, 1.062, 1.060, 1.058],
        "refl_std": [0.023, 0.008, 0.008, 0.012, 0.016, 0.019, 0.021, 0.026, 0.038],
    },
    "Xc": {
        "refl_mean": [0.920, 0.969, 1.019, 1.038, 1.049, 1.054, 1.047, 1.037, 1.020],
        "refl_std": [0.030, 0.012, 0.008, 0.010, 0.011, 0.012, 0.015, 0.020, 0.033],
    },
    "Xe": {
        "refl_mean": [0.921, 0.948, 1.032, 1.060, 1.082, 1.094, 1.093, 1.088, 1.078],
        "refl_std": [0.039, 0.023, 0.019, 0.033, 0.041, 0.039, 0.039, 0.041, 0.050],
    },
    "Xk": {
        "refl_mean": [0.900, 0.959, 1.033, 1.061, 1.084, 1.097, 1.098, 1.098, 1.098],
        "refl_std": [0.037, 0.012, 0.010, 0.013, 0.014, 0.018, 0.020, 0.023, 0.034],
    },
}

==> space_classy-0.8.6-py3-none-any.whl: classy/taxonomies/bus.py <==
from classy import core

WAVE = [0.44, 0.50, 0.60, 0.65, 0.70, 0.75, 0.80, 0.85, 0.92]
CLASSES = [
    "B",
    "Cg",
    "Cgh",
    "C",
    "Ch",
    "Cb",
    "D",
    "T",
    "Xc",
    "Xk",
    "Xe",
    "X",
    "Ld",
    "K",
    "L",
    "O",
    "Q",
    "Sq",
    "Sl",
    "S",
    "Sk",
    "Sr",
    "Sa",
    "R",
    "A",
    "V",
]


def load_templates():
    """Load the spectral templates of the Bus classes.

    Returns
    -------
    dict
        Dictionary with classes (str) as key and templates as values (classy.Spectrum).
    """

    templates_ = {}

    for class_, props in TEMPLATES.items():
        refl = props["refl_mean"]
        refl_err = props["refl_std"]

        template = core.Spectrum(
            wave=WAVE + [0.55],
            refl=refl + [1],
            refl_err=refl_err + [0],
            class_=class_,
            source="Bus and Binzel 2002",
        )
        templates_[class_] = template
    return templates_


# Table III in Bus 2002
TEMPLATES = {
    "A": {
        "refl_mean": [0.708, 0.868, 1.109, 1.214, 1.298, 1.311, 1.250, 1.187, 1.143],
        "refl_std": [0.026, 0.014, 0.013, 0.026, 0.038, 0.045, 0.059, 0.066, 0.063],
    },
    "B": {
        "refl_mean": [1.008, 1.004, 0.989, 0.985, 0.978, 0.975, 0.969, 0.961, 0.938],
        "refl_std": [0.022, 0.008, 0.007, 0.011, 0.015, 0.019, 0.023, 0.026, 0.039],
    },
    "C": {
        "refl_mean": [0.936, 0.979, 1.007, 1.013, 1.014, 1.016, 1.014, 1.008, 0.993],
        "refl_std": [0.025, 0.009, 0.009, 0.011, 0.013, 0.015, 0.017, 0.022, 0.034],
    },
    "Cb": {
        "refl_mean": [0.981, 0.995, 0.999, 1.002, 1.002, 1.005, 1.003, 0.994, 0.979],
        "refl_std": [0.018, 0.007, 0.005, 0.008, 0.010, 0.012, 0.015, 0.020, 0.031],
    },
    "Cg": {
        "refl_mean": [0.852, 0.945, 1.018, 1.028, 1.027, 1.025, 1.026, 1.022, 1.007],
        "refl_std": [0.013, 0.013, 0.012, 0.020, 0.020, 0.023, 0.027, 0.036, 0.044],
    },
    "Cgh": {
        "refl_mean": [0.870, 0.962, 0.997, 0.985, 0.972, 0.973, 0.987, 0.991, 0.980],
        "refl_std": [0.025, 0.014, 0.016, 0.027, 0.035, 0.038, 0.042, 0.047, 0.059],
    },
    "Ch": {
        "refl_mean": [0.941, 0.986, 0.991, 0.983, 0.977, 0.982, 0.991, 0.996, 0.993],
        "refl_std": [0.030, 0.010, 0.008, 0.013, 0.018, 0.021, 0.024, 0.028, 0.037],
    },
    "D": {
        "refl_mean": [0.882, 0.951, 1.046, 1.098, 1.150, 1.199, 1.222, 1.247, 1.287],
        "refl_std": [0.029, 0.012, 0.005, 0.006, 0.010, 0.015, 0.018, 0.026, 0.067],
    },
    "K": {
        "refl_mean": [0.863, 0.943, 1.043, 1.087, 1.121, 1.138, 1.125, 1.110, 1.085],
        "refl_std": [0.024, 0.010, 0.010, 0.016, 0.019, 0.018, 0.020, 0.023, 0.038],
    },
    "L": {
        "refl_mean": [0.818, 0.922, 1.066, 1.130, 1.179, 1.207, 1.201, 1.193, 1.188],
        "refl_std": [0.031, 0.013, 0.012, 0.020, 0.025, 0.024, 0.021, 0.020, 0.042],
    },
    "Ld": {
        "refl_mean": [0.799, 0.913, 1.080, 1.163, 1.228, 1.270, 1.280, 1.282, 1.288],
        "refl_std": [0.042, 0.021, 0.018, 0.027, 0.029, 0.034, 0.038, 0.041, 0.067],
    },
    "O": {
        "refl_mean": [0.878, 0.952, 1.022, 1.042, 1.057, 1.036, 0.958, 0.870, 0.798],
        "refl_std": [0.026, 0.007, 0.006, 0.009, 0.012, 0.011, 0.015, 0.033, 0.048],
    },
    "Q": {
        "refl_mean": [0.830, 0.930, 1.047, 1.087, 1.118, 1.107, 1.041, 0.952, 0.873],
        "refl_std": [0.044, 0.018, 0.018, 0.027, 0.032, 0.031, 0.023, 0.019, 0.032],
    },
    "R": {
        "refl_mean": [0.792, 0.907, 1.073, 1.145, 1.209, 1.224, 1.110, 0.971, 0.889],
        "refl_std": [0.016, 0.006, 0.005, 0.006, 0.010, 0.010, 0.014, 0.015, 0.033],
    },
    "S": {
        "refl_mean": [0.813, 0.920, 1.060, 1.121, 1.170, 1.188, 1.145, 1.084, 1.034],
        "refl_std": [0.028, 0.011, 0.012, 0.018, 0.023, 0.024, 0.024, 0.028, 0.040],
    },
    "Sa": {
        "refl_mean": [0.748, 0.892, 1.094, 1.178, 1.243, 1.260, 1.216, 1.150, 1.091],
        "refl_std": [0.029, 0.011, 0.010, 0.014, 0.014, 0.019, 0.025, 0.036, 0.059],
    },
    "Sk": {
        "refl_mean": [0.859, 0.939, 1.039, 1.082, 1.115, 1.130, 1.092, 1.039, 1.001],
        "refl_std": [0.029, 0.011, 0.008, 0.010, 0.012, 0.013, 0.009, 0.011, 0.022],
    },
    "Sl": {
        "refl_mean": [0.790, 0.909, 1.076, 1.149, 1.209, 1.237, 1.205, 1.158, 1.131],
        "refl_std": [0.025, 0.009, 0.009, 0.013, 0.015, 0.017, 0.019, 0.026, 0.042],
    },
    "Sq": {
        "refl_mean": [0.851, 0.938, 1.039, 1.082, 1.115, 1.120, 1.069, 1.000, 0.936],
        "refl_std": [0.031, 0.011, 0.009, 0.017, 0.022, 0.028, 0.028, 0.028, 0.034],
    },
    "Sr": {
        "refl_mean": [0.777, 0.904, 1.069, 1.137, 1.188, 1.193, 1.123, 1.030, 0.936],
        "refl_std": [0.046, 0.023, 0.016, 0.024, 0.028, 0.031, 0.032, 0.028, 0.038],
    },
    "T": {
        "refl_mean": [0.896, 0.956, 1.041, 1.083, 1.119, 1.149, 1.163, 1.174, 1.184],
        "refl_std": [0.027, 0.008, 0.011, 0.016, 0.019, 0.015, 0.015, 0.021, 0.037],
    },
    "V": {
        "refl_mean": [0.808, 0.916, 1.063, 1.124, 1.176, 1.183, 1.048, 0.879, 0.745],
        "refl_std": [0.052, 0.024, 0.019, 0.036, 0.049, 0.049, 0.039, 0.0460, 0.056],
    },
    "X": {
        "refl_mean": [0.940, 0.977, 1.013, 1.030, 1.045, 1.057, 1.062, 1.060, 1.058],
        "refl_std": [0.023, 0.008, 0.008, 0.012, 0.016, 0.019, 0.021, 0.026, 0.038],
    },
    "Xc": {
        "refl_mean": [0.920, 0.969, 1.019, 1.038, 1.049, 1.054, 1.047, 1.037, 1.020],
        "refl_std": [0.030, 0.012, 0.008, 0.010, 0.011, 0.012, 0.015, 0.020, 0.033],
    },
    "Xe": {
        "refl_mean": [0.921, 0.948, 1.032, 1.060, 1.082, 1.094, 1.093, 1.088, 1.078],
        "refl_std": [0.039, 0.023, 0.019, 0.033, 0.041, 0.039, 0.039, 0.041, 0.050],
    },
    "Xk": {
        "refl_mean": [0.900, 0.959, 1.033, 1.061, 1.084, 1.097, 1.098, 1.098, 1.098],
        "refl_std": [0.037, 0.012, 0.010, 0.013, 0.014, 0.018, 0.020, 0.023, 0.034],
    },
}
